@@ -128,15 +128,18 @@ impl SnapshotContainer {
                     pending_vec.sort_by_key(|pending| pending.line);
                     for (id, pending) in pending_vec.into_iter().enumerate() {
                         if let Some(new) = pending.new {
-                            snapshots.push(PendingSnapshot {
-                                id,
-                                old: pending.old,
-                                new,
-                                op: Operation::Skip,
-                                line: Some(pending.line),
-                            });
-                            patcher.add_snapshot_macro(pending.line as usize);
-                            have_new = true;
+                            if patcher.add_snapshot_macro(pending.line as usize) {
+                                snapshots.push(PendingSnapshot {
+                                    id,
+                                    old: pending.old,
+                                    new,
+                                    op: Operation::Skip,
+                                    line: Some(pending.line),
+                                });
+                                have_new = true;
+                            } else {
+                                // this is an outdated snapshot and the file changed.
+                            }
                         }
                     }
                     Some(patcher)
@@ -221,7 +224,9 @@ impl SnapshotContainer {
             for snapshot in self.snapshots.iter() {
                 match snapshot.op {
                     Operation::Accept => {
-                        fs::rename(&self.snapshot_path, &self.target_path)?;
+                        let snapshot = Snapshot::from_file(&self.snapshot_path)?;
+                        snapshot.save(&self.target_path)?;
+                        fs::remove_file(&self.snapshot_path)?;
                     }
                     Operation::Reject => {
                         fs::remove_file(&self.snapshot_path)?;
